==> deepin-calculator_6.0.0.tar.xz: BUILD/translations/deepin-calculator_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro na expresión</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda a memoria</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Borrar historial</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard and scientific modes.</source>
        <translation>A calculadora é unha calculadora de escritorio fácil de usar, soportando modos estándar e científicos.</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Estándar</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Científico</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar a memoria do elemento</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda a memoria</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Recordo de memoria</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Engadir ao elemento de memoria</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Engadir memoria</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar un elemento de memoria</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Restar memoria</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Almacenamento de memoria</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar a memoria do elemento</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Engadir ao elemento de memoria</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar un elemento de memoria</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>No hai nada gardado na memoria</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro na expresión</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Erro na expresión</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Non hai historial</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.9.tar.xz: BUILD/translations/deepin-calculator_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro na expresión</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda a memoria</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Borrar historial</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>Usar o separador de miles</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>Usar o separador de dez mil</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Dersfacer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refacer</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Estándar</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Científico</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>Calculator é unha calculadora de escritorio fácil de usar, que admite os modos estándar, científico e programador.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programador</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar a memoria do elemento</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Borrar toda a memoria</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Recordo de memoria</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Engadir ao elemento de memoria</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Engadir memoria</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar un elemento de memoria</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Restar memoria</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Almacenamento de memoria</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Borrar a memoria do elemento</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Engadir ao elemento de memoria</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Restar un elemento de memoria</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>No hai nada gardado na memoria</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro na expresión</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Cambio aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Cambio lóxico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Cambio circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Xirar a través de facer o cambio circular</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Cambio aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Cambio lóxico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Cambio circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Xirar a través de facer o cambio circular</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro na expresión</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Erro na expresión</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Non hai historial</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
</TS>
